Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(363)

Unified Diff: chrome/renderer/extensions/extension_process_bindings.h

Issue 173166: Implement granular cross-origin XHR for extensions. (Closed)
Patch Set: some cleanup Created 11 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/renderer/extensions/extension_process_bindings.h
diff --git a/chrome/renderer/extensions/extension_process_bindings.h b/chrome/renderer/extensions/extension_process_bindings.h
index dd212c5c260a4bdc7d4fa39ec836d69606aefd92..bea3e9185cd549592af0bfdee90abf7f23b2e0cf 100644
--- a/chrome/renderer/extensions/extension_process_bindings.h
+++ b/chrome/renderer/extensions/extension_process_bindings.h
@@ -13,6 +13,9 @@
#include "v8/include/v8.h"
+class GURL;
+class URLPattern;
+
class ExtensionProcessBindings {
public:
static void SetFunctionNames(const std::vector<std::string>& names);
@@ -27,9 +30,13 @@ class ExtensionProcessBindings {
static void SetPageActions(const std::string& extension_id,
const std::vector<std::string>& page_actions);
- // Sets the permissions for a particular extension.
- static void SetPermissions(const std::string& extension_id,
- const std::vector<std::string>& permissions);
+ // Sets the API permissions for a particular extension.
+ static void SetAPIPermissions(const std::string& extension_id,
+ const std::vector<std::string>& permissions);
+
+ // Sets the host permissions for a particular extension.
+ static void SetHostPermissions(const GURL& extension_url,
+ const std::vector<URLPattern>& permissions);
// Check if the extension in the currently running context has permission to
// access the given extension function. Must be called with a valid V8

Powered by Google App Engine
This is Rietveld 408576698